@@ -45,7 +45,7 @@ class AsyncBufferedConsumer(SynchronousBufferedConsumer):
 
     Because AsyncBufferedConsumer holds events until the `flush_after` timeout
     or an endpoint queue hits the size of _max_queue_size, you should call
-    flush(async=False) before you terminate any process where you have been
+    flush(async_=False) before you terminate any process where you have been
     using the AsyncBufferedConsumer.
     '''
 
@@ -53,8 +53,21 @@ class AsyncBufferedConsumer(SynchronousBufferedConsumer):
     ALL = "ALL"
     ENDPOINT = "ENDPOINT"
 
-    def __init__(self, flush_after=timedelta(0, 10), flush_first=True, max_size=20,
-        events_url=None, people_url=None, *args, **kwargs):
+    def __init__(
+        self,
+        flush_after=timedelta(0, 10),
+        flush_first=True,
+        max_size=20,
+        events_url=None,
+        people_url=None,
+        import_url=None,
+        request_timeout=None,
+        groups_url=None,
+        api_host="api.mixpanel.com",
+        retry_limit=4,
+        retry_backoff_factor=0.25,
+        verify_cert=True,
+    ):
         '''
         Create a new instance of a AsyncBufferedConsumer class.
 
@@ -65,13 +78,30 @@ class AsyncBufferedConsumer(SynchronousBufferedConsumer):
         the consumer receives
         :param max_size (int): the number of events in queue that will trigger
         the queue to be flushed asynchronously
-        :param events_url: the Mixpanel API URL that track events will be sent to
-        :param people_url: the Mixpanel API URL that people events will be sent to
+        :param events_url: Mixpanel API URL that track events will be sent to
+        :param people_url: Mixpanel API URL that people events will be sent to
+        :param import_url: Mixpanel API URL that import events will be sent to
+        :param request_timeout: Connection timeout in seconds
+        :param groups_url: Mixpanel API URL that groups events will be sent to
+        :param api_host: Mixpanel API domain for all requests unless overriden by above URLs
+        :param retry_limit: Number of times to retry each request in case of an error, 0
+        to fail after first attempt.
+        :param retry_backoff_factor: Factor which controls sleep duration between retries:
+        sleep_seconds = backoff_factor * (2 ^ (retry_count - 1))
+        :param verify_cert: Whether to verify the server certificate. "True" is
+        recommended.
         '''
         super(AsyncBufferedConsumer, self).__init__(
             max_size=max_size,
             events_url=events_url,
-            people_url=people_url
+            people_url=people_url,
+            import_url=import_url,
+            request_timeout=request_timeout,
+            groups_url=groups_url,
+            api_host=api_host,
+            retry_limit=retry_limit,
+            retry_backoff_factor=retry_backoff_factor,
+            verify_cert=verify_cert,
         )
 
         # remove the minimum max size that the SynchronousBufferedConsumer
@@ -133,7 +163,7 @@ class AsyncBufferedConsumer(SynchronousBufferedConsumer):
         return False
 
 
-    def send(self, endpoint, json_message):
+    def send(self, endpoint, json_message, api_key=None):
         '''
         Record an event or a profile update. Calls to send() will store
         the given message in memory, and (when enough messages have been stored)
@@ -147,6 +177,8 @@ class AsyncBufferedConsumer(SynchronousBufferedConsumer):
         :type endpoint: str (one of 'events' or 'people')
         :param json_message: A json message formatted for the endpoint.
         :type json_message: str
+        :param api_key: Your Mixpanel project's API key
+        :type api_key: str
         :raises: MixpanelException
         '''
         if endpoint not in self._async_buffers:
@@ -155,6 +187,9 @@ class AsyncBufferedConsumer(SynchronousBufferedConsumer):
         buf = self._async_buffers[endpoint]
         buf.append(json_message)
 
+        if api_key is not None:
+            self._api_key = api_key
+
         should_flush = self._should_flush(endpoint)
 
         if should_flush == self.ALL:
@@ -163,7 +198,7 @@ class AsyncBufferedConsumer(SynchronousBufferedConsumer):
             self._flush_endpoint(endpoint)
 
 
-    def flush(self, endpoint=None, async=True):
+    def flush(self, endpoint=None, async_=True):
         '''
         Send all remaining messages to Mixpanel. AsyncBufferedConsumers will
         flush automatically when you call send(), but you will need to call
@@ -184,7 +219,7 @@ class AsyncBufferedConsumer(SynchronousBufferedConsumer):
 
         flushing = False
 
-        if async:
+        if async_:
             # this flush lock is used to guarantee that only one flushing_thread
             # is ever alive.
             with self.flush_lock:
@@ -241,11 +276,11 @@ class AsyncBufferedConsumer(SynchronousBufferedConsumer):
                 self._buffers[key].append(buf.pop(0))
 
 
-    def _flush_endpoint(self, endpoint, async=True):
+    def _flush_endpoint(self, endpoint, async_=True):
         # we override flush with endpoint so as to keep all the
         # threading logic in one place, while still allowing individual
         # endpoints to be flushed
-        self.flush(endpoint=endpoint, async=async)
+        self.flush(endpoint=endpoint, async_=async_)
 
 
     def _sync_flush(self, endpoint=None):
